View of a pier and lighthouse with small mooored vessels in foreground,
 from
https://www.europeana.eu/en/item/2022362/_Royal_Museums_Greenwich__http___collections_rmg_co_uk_collections_objects_117930
